module.exports = defineTest({
	description: 'imports a dependency from a separate module'
});
